﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

namespace TeeTest
{
    public delegate void CollectorHistoryUpdatedEventHandler(object sender, CollectorHistoryUpdatedEventArgs e);

    public class CollectorHistoryUpdatedEventArgs : EventArgs
        {
            private DataRow _row;
            public CollectorHistoryUpdatedEventArgs(DataRow row)
            {
                this._row = row;
            }
            public DataRow Row
            {
                get
                {
                    return _row;
                }
            }
        } 
    class CollectorTaskSimulator
    {
        protected DataTable _dataTable;
        public event CollectorHistoryUpdatedEventHandler HistoryUpdated;

       

        public  DataTable dataTable
        {
            get { return _dataTable; }
            set { _dataTable = value;  }
        }
        public bool InitDataProcessing()
        {
            dataTable = new DataTable();
            DataColumn col = new DataColumn("DateTime", Type.GetType("System.DateTime"));
            dataTable.Columns.Add(col);
            //Add series
            col = new DataColumn("USR", Type.GetType("System.Double"));
            col.ExtendedProperties.Add("RndGen", new Random());
            col.ExtendedProperties.Add("RndGenBasis", 10);
            dataTable.Columns.Add(col);
            col = new DataColumn("Ampl", Type.GetType("System.Double"));
            col.ExtendedProperties.Add("RndGen", new Random());
            col.ExtendedProperties.Add("RndGenBasis", 50);
            dataTable.Columns.Add(col);
            col = new DataColumn("Impedanz", Type.GetType("System.Double"));
            col.ExtendedProperties.Add("RndGen", new Random());
            col.ExtendedProperties.Add("RndGenBasis", 100);
            dataTable.Columns.Add(col);
            col = new DataColumn("ID1", Type.GetType("System.Double"));
            col.ExtendedProperties.Add("RndGen", new Random());
            col.ExtendedProperties.Add("RndGenBasis", 150);
            dataTable.Columns.Add(col);
            col = new DataColumn("Error", Type.GetType("System.Double"));
            col.ExtendedProperties.Add("RndGen", new Random());
            col.ExtendedProperties.Add("RndGenBasis", 200);
            dataTable.Columns.Add(col);
            

            return true;
        }

        public void UpdateHistory()
        {
            try
            {
                DataRow newRow = dataTable.NewRow();
                DateTime cNow = DateTime.Now;
                newRow[0] = cNow;
                for (int i = 1; i < dataTable.Columns.Count; i++)
                {
                    Random rd = dataTable.Columns[i].ExtendedProperties["RndGen"] as Random;
                    newRow[i] = rd.Next((int)dataTable.Columns[i].ExtendedProperties["RndGenBasis"]);
                    
                }
                dataTable.Rows.Add(newRow);
                if (HistoryUpdated != null)
                    HistoryUpdated(this, new CollectorHistoryUpdatedEventArgs(newRow));
            }
            catch (Exception ex) { }
        }

        public void Start()
        {
            Thread thread = new Thread(new ParameterizedThreadStart(CallBackFunction));
            thread.SetApartmentState(ApartmentState.STA);
            thread.Start(this);
            
        }

        public static void CallBackFunction(object lpParam)
        {
            CollectorTaskSimulator cthis = (CollectorTaskSimulator)lpParam;
            while (true)
            {
               cthis.UpdateHistory();
               Thread.Sleep(100);

            }
        }

    }
}
