﻿
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Xml;

namespace TeeTest
{
    public partial class Form1 : Form
    {
        CollectorTaskSimulator collectorTask;
        bool Drawing = false;
        public Form1()
        {
            InitializeComponent();
            SetChartStartPosition();
            CreateCollector();
            ConnectChart(this.dataTabledirect.Checked);
            collectorTask.Start();
        }

        public void CreateCollector()
        {
            collectorTask = new CollectorTaskSimulator();
            collectorTask.InitDataProcessing();
            collectorTask.HistoryUpdated += new CollectorHistoryUpdatedEventHandler(OnHistoryUpdated);
        }


        public void ConnectChart(bool direct)
        {
            ChartControl.Series.RemoveAllSeries();
            DataTable dataTable = collectorTask.dataTable;
            DataColumn timeCol = dataTable.Columns[0];
            foreach (DataColumn col in dataTable.Columns)
            {
                if (col == dataTable.Columns[0]) continue;

                Steema.TeeChart.Styles.Line lineSeries = new Steema.TeeChart.Styles.Line();
                ChartControl.Series.Add(lineSeries);
                if (direct)
                {
                    lineSeries.DataSource = dataTable;
                    lineSeries.YValues.DataMember = col.ToString();

                    lineSeries.XValues.DataMember = timeCol.ToString();
                }
                lineSeries.XValues.DateTime = true;
                lineSeries.Title = col.ToString();

                lineSeries.Active = true;
                lineSeries.Pointer.Style = Steema.TeeChart.Styles.PointerStyles.Diamond;
                lineSeries.Pointer.Visible = true;
                lineSeries.Pointer.Pen.Visible = false;
                lineSeries.Pointer.Brush.Visible = true;
                lineSeries.Pointer.HorizSize = 3;
                lineSeries.Pointer.VertSize = 3;
                lineSeries.ColorEach = false;

            }
        }

        private void OnHistoryUpdated(object sender, CollectorHistoryUpdatedEventArgs e)
        {

            if (this.dataTabledirect.Checked)
            {
                if (this.checkDrawing.Checked == false)
                    Drawing = false;
                for (int i = 0; i < ChartControl.Series.Count; i++)
                {
                    if (ChartControl[i].Active && Drawing == false)
                        ChartControl[i].CheckDataSource();
                }
            }
            else
            {
                try
                {
                    for (int i = 0; i < ChartControl.Series.Count; i++)
                    {
                        DataRow dRow = e.Row;
                        DateTime dt = (DateTime)dRow[0];
                        double val = (double)dRow[i + 1];
                        ChartControl[i].Add(dt, val);
                    }
                }
                catch(Exception ex) 
                {
                    MessageBox.Show(ex.Message, "OnHistoryUpdated Exception");
                }
               
            }
            if(this.invalidateChart.Checked)
                ChartControl.Invalidate(); //necessary, that it keeps updating
        }

        protected void SetChartStartPosition()
        {
            ChartControl.Aspect.View3D = false;
            ChartControl.Header.Visible = false;
            ChartControl.Axes.Top.Labels.Visible = false;
            ChartControl.Axes.Left.Automatic = true;
            ChartControl.Panel.Bevel.Inner = Steema.TeeChart.Drawing.BevelStyles.None;
            ChartControl.Panel.Bevel.Outer = Steema.TeeChart.Drawing.BevelStyles.None;
            ChartControl.Zoom.Active = true;
            ChartControl.Legend.Alignment = Steema.TeeChart.LegendAlignments.Bottom;
            ChartControl.Legend.LegendStyle = Steema.TeeChart.LegendStyles.Series;
            ChartControl.Legend.Shadow.Size = System.Drawing.Size.Empty;
            ChartControl.AutoRepaint = false;
            ChartControl.BeforeDraw += new Steema.TeeChart.PaintChartEventHandler(OnChartBeforeDraw);
            ChartControl.AfterDraw += new Steema.TeeChart.PaintChartEventHandler(OnChartAfterDraw);
        }

        void OnChartBeforeDraw(object sender, Steema.TeeChart.Drawing.Graphics3D g)
        {
            Drawing = true;
        }

        void OnChartAfterDraw(object sender, Steema.TeeChart.Drawing.Graphics3D g)
        {
            Drawing = false;
        }

        private void ChartControl_DoubleClick(object sender, EventArgs e)
        {
            ChartControl.ShowEditor();
        }

        private void OnCheckChanged(object sender, EventArgs e)
        {
            ConnectChart(this.dataTabledirect.Checked);
        }

        private void autoRepaint_CheckedChanged(object sender, EventArgs e)
        {
            ChartControl.AutoRepaint = this.autoRepaint.Checked;
        }

    }
}
